-- INSTRUCTIONS
-- Replace tablespace name alex_4k with the name of a large 4k tablespace.
-- In the event of failure, you can rerun from start after correcting the error.
-- Alex Levy t/a http;//www.sustainablesoftware.net, March 2014.

-- Clear everything down on a rerun.
-- At DB2 10.1.2, sysproc.admin_drop_schema is a bit flaky in that it sometimes tries to recreate an existing error table.
set current schema = current user ;
begin
    declare v_statement varchar(150);--
    declare v_count smallint default 0 ;--
    for v_loop as select tabname from syscat.tables where tabschema = 'SUDOKU' and type = 'T'
    do
        set v_statement = 'drop table sudoku.' || tabname ;--
        execute immediate v_statement ;--
    end for ;--
    for v_loop as select procname from syscat.procedures where procschema = 'SUDOKU'
    do
        set v_statement = 'drop procedure sudoku.' || procname ;--
        execute immediate v_statement ;--
    end for ;--
    for v_loop as select pkgname from syscat.packages where pkgschema = 'SUDOKU'
    do
        set v_statement = 'drop package sudoku.' || pkgname ;--
        execute immediate v_statement ;--
    end for ;--
    set v_count = (select 1 from syscat.tables where tabschema = 'ERRSCHEMA' and tabname = 'ERRTAB' and type = 'T') ; --
    if  v_count = 1 then
        set v_statement = 'drop table ERRSCHEMA.ERRTAB' ;--
        execute immediate v_statement ;--
    end if ;--
end ;

set current path "SYSIBM","SYSFUN","SYSPROC","SYSIBMADM",current user ;
create table sudoku.dropme (col1 smallint) ;
call sysproc.admin_drop_schema('SUDOKU',NULL,'ERRSCHEMA','ERRTAB') ;
create schema sudoku ;
comment on schema sudoku is 'Schema for sudoku puzzle-solving database objects.' ;
set current schema sudoku ;
set path = current path, sudoku ;

create table row_set (
row# smallint not null primary key
) in alex_4k
;

alter table row_set add constraint row_c1 check (row# between 1 and 9)
;
insert into row_set (row#) values (1),(2),(3),(4),(5),(6),(7),(8),(9)
;

create table column_set (
column# smallint not null primary key
) in alex_4k
;

alter table column_set add constraint column_c1 check (column# between 1 and 9)
;
insert into column_set (column#) values (1),(2),(3),(4),(5),(6),(7),(8),(9)
;

create table cell_value (
row#    smallint not null,
column# smallint not null, 
square# smallint not null generated always as (
                          case when row# between 1 and 3
                               then case when column# between 1 and 3 then 1
                                         when column# between 4 and 6 then 2
                                         when column# between 7 and 9 then 3
                                    end
                               when row# between 4 and 6                                                         
                               then case when column# between 1 and 3 then 4
                                         when column# between 4 and 6 then 5
                                         when column# between 7 and 9 then 6
                                    end
                               when row# between 7 and 9                                                         
                               then case when column# between 1 and 3 then 7
                                         when column# between 4 and 6 then 8
                                         when column# between 7 and 9 then 9
                                    end
                          end),
cell_actual_value smallint	
) in alex_4k
; 
create unique index cell_value_u1 on cell_value (row# asc, column# asc)
cluster allow reverse scans
;
alter table cell_value add constraint cell_value_pk primary key (row#, column#)
;
insert into cell_value (row#,column#) select * from row_set,column_set 
;
alter table cell_value add constraint cell_value__row_set_fk foreign key (row#) references row_set (row#) not enforced enable query optimization; 
alter table cell_value add constraint cell_value__column_set_fk foreign key (column#) references column_set (column#) not enforced enable query optimization; 
alter table cell_value add constraint cell_value_c1 check (cell_actual_value is null or cell_actual_value between 1 and 9); 

create table cell_possible_value like cell_value including column defaults in alex_4k ;
alter table  cell_possible_value rename column cell_actual_value to possible_value ;
reorg table  cell_possible_value ;

create table row_candidate (
row#    smallint not null,
cell1	smallint not null,
cell2	smallint not null,
cell3	smallint not null,
cell4	smallint not null,
cell5	smallint not null,
cell6	smallint not null,
cell7	smallint not null,
cell8	smallint not null,
cell9	smallint not null,
rowrank integer not null 
) in alex_4k
;

create table solution (
row# 	smallint not null,
answer 	char(18)
) in alex_4k
;

create table tempwork
(r#  smallint not null,
 c#  smallint not null,
 s#  smallint not null,
 pv# smallint not null
) in alex_4k
;

create table cell_candidate (
row#	smallint not null,
column# smallint not null,
square# smallint not null,
cell_value smallint not null
) in alex_4k
;

create table startdata  (
row#    smallint not null,
rowdata integer not null
) in alex_4k
;

create or replace variable sum_row_cells smallint constant 45 ;
create or replace variable sum_row_cell_ids smallint default 0 ;
create or replace variable sum_col_cell_ids smallint default 0 ;

comment on variable sudoku.sum_row_cells is 'Constrained sum of cell values [1-9] for each row and column.' ;
comment on variable sudoku.sum_row_cell_ids is 'Constrained sum of cell identifiers for a given row: each cell id is numbered as (row# * 10) + column#, so this variable will contain sum(11...19), sum(21...29) and so on. Alternate calculation is (row# * 10) + sum_row_cells.' ;
comment on variable sudoku.sum_col_cell_ids is 'Constrained sum of cell identifiers for a given column: each cell id is numbered as (row# * 10) + column#, so this variable will contain sum(11,21,31...91), sum(22,32,42..92) and so on. Alternate calculation is (col# * 9) + sum(row# * 10).' ;

-- current solution eschews arrays as a programmatic, non-set based hack:
-- create or replace type sudoku_array as smallint array[9] ;
-- create or replace type sudoku_super_array as sudoku_array array[9] ;
-- create or replace variable s_row_array sudoku_array ;
-- create or replace variable s_col_array sudoku_array ;
-- create or replace variable s_array sudoku_super_array ;
-- Reminder to self on array operations:
-- set sa[column#] = ...
-- set n = cardinality(sa)
-- set x=ARRAY[select ...]
-- array_delete, array_next/prior/first/last
-- array_exists()
-- select array_agg(columnvalue order by columnnum)
-- UNNEST table function

create or replace procedure sudoku.sudoku_bruteforce()  WRAPPED SQL10012 ablGWmdiWmtqTmdmTmtKTmtuUmZKUmZCUoti2ndq3idaWmdaWmta5nZjUzcaGicaGIkkOIOCtb6FyhldPD3XBA1dI4Fhcr0gArmpVqQ6Egjd_2UWX2RGbgo2xv5V5MxFM1JuFoEfXStyePfAIxkmDDTXhHwoBDkhxi4198JA0tNwLc8bqPMQtpgsVDzJHINudvaA5cChpjzqRetGQ5IgenivEftGwgQ5W_z4k5LEOQ1OIiSZBXlUljf17eeQpo5gFnZhzWKKx5OuzztGpCrghXYEEkQfFloOJHWkSDPZMmF4G12B_sYrPHzsWsLpVKXnZ9pG7n1mmBpVAqcEn4Lb_UGpXoALkkUkWKWE8kT27ys93KeuQEziu9v92cqgipBC:o4QHYJnxcQ1m2pjx2SL3CH6x4r79XP8:F9IFhtBF8mZU52Lvc4cJIpQit6BZNUdp1qnBP_wz71A7Ra1IRcAqVyr_tyYRTTVrP2TRfXWifFOyxswAHMbBO:dIJg5lvGpbrnNcsP7YUjHKDN2WaFgDefLl04EsuLiv5gl1FcbEyeRCKa5a3LBZkRDD8kSCtMpQCaumHHwaLPI5FR9zOkN1dAIzn:J6c83JZ0n5pUsivs5QcjgG969kKeYIB8NHHL6jZMwTkEatbxjm2WbHY1BXvRoiq67ujw3VMaudDocvWey8kmYJWH5OmuBaDCPrIfmZRKA4E3txrgCSHSrg3QSsnoIYKu9T:55Kg9sieE73Mzr1_V7GkLNyeepBf0rxUtirUlZOsw8JiACqbcjdjRvwbQLxypaAaEdqXs34Aju6BwVwrThUyLST38ofVZtZBGbXgUY7UUO:yJWxbqqXDMzWC4bqzFuzG2fqWc74B4e2Bv:vrTZRuLV9l8oiSdFa3klXzzoZqZlpCnxVvd9vaMwZcarDfXCFoHmsKpJkyS9tQayyOzLR6bTuTREgAyH4jnjQJ2kYSiqheKij3eHQ3YkXW:dPgG:UgJzjDdttmf1FLhIkBrupOoDJIUHbwQGWNoxIzq0OerseiCNVq_QDLJW72qtLs09ITAmsJyZ8LAo_iTD0vx00H1dKvsmzyW8AOByaM7s_:7DxsIUDYTy02PObs86g4MTYW4p3oCeSpv6vfwx4xbfp80Dd2gzYc3KdSWUfjM1kqv0rQiIiiIbpeRssgm0Ea4E4TxttEpV3ms56BvbdK0ItZKA78UnCQh4xzQ7bJzTiDOFCxaoScLM5XRkPMfXiN_Ot_wuxobl24z3gxJ1RZPC__RT0Ks3GB0NbGbkg2VLlAESrRw_mC4mW5tIJM8v8274p9uHtnh7G_1epaMcpsWsma8j6ZQY3oNbSR4fHI9WqMzFWzKpGWmVVwJV8_iviVBk0z2hudcDJGRWTd4rqwpB2y5MOmMUCLbd:8rGLbU6rm5O30xYAliD9ri7HN1_Os:jGf0auBKB2cGJoBzd7LcWkI9dgNi4_Av6BGXHdWpBLD7OskanmHuJM:ME8GScmUHHc2yJWB80Qv3E1aoc2YdPh:GsskYyFfFK2VuCdiS7Gk07UbwxZsLfkaVpsADHBmfwFcbPwupjb2mjqZT3Ck24RbhmuI1hxdIBBpsgALjp:9PVBFLCTWS69pH7ObokSeKhNKZdanhnF3wLm8VKyOcww_dbATOuZMc2G_61vT0I5b:IhxAz9x3mNi2hqCAApGclX8QdHPAuDc0OyXk9ABhooGjukiG9M9oQCWuwXAeeJ4stidGI6gH6uv3pVFsh4mInmRIoHLiwQs8AxDi:5rgVOORb52F3LR5XIZvRGxhoQHFhQJJgHk5sNiAUTxo3i58r0qLpO2emoGR2aUI4IDnaTWrOG1lDuM6QUYuflwfPDU_Y59YtZTqiGpgC1xDfvb_w6SKb_Vd4rRxvjKYnkoadvLoilmMJwys7zHQefY4dxdB_MZBlW_3fYIEaXEzG14vQSr7Z29tMbghbNIE_r4dMrIpv7gBLKO36f6I7LRH0nsZsSJoF26:hw:I_l:WqE6nK6q9GsX6i2Ql9ftXojJSZ2VHU9xYo84ULUYeyRYmYqM7Ad8Xi4P9NW2hUinygp4v:_XXLZspG:VzkDC3a_rOu:8Y4b9urMshIJfyUqWC39NOU3aVSNIkyVs:HIzc8q0ks52CQhv0VHl9gVCd2ZeCtSf_S8:h4Jx1oMMjSlCEljQwiZPOdg9xLAQqgI6PC82DGiFnxAe2Lq8TKP80Mtj8LUXrQalaF6bnTTm9A6Q0MQMHMNj:9Y3ICDoWq3qFzumKurRrbRKgaqX:WXLQUeRAwKsvJisQo:bQjBb_BvtWTSAVIuEbxT1GOJ21ArVfjp7l_38TS4n2QTFuHInf3c1P9jVFTZRiLXBp2OJ0L_wmQ9V67Vi3GIGbu3lJCfScAhprr5lbOLVNsmmcftQqUpOLOtRonKZVGGQQYIzEXiIZzbJRKqKRUF:7o2krKjB0otbgh4m6WXDuPXSgIrr0ZOgK_cDTBkkl9QLlqIC23dOjTOQIp4AZ_MWGokIHDAQgkxRlVsWwWaWHRDszJQ_kPXjVCQeAYqPsZ6olFgdgSN0jAjum6ENm4VQdWU:lxXOc1OEa0ddHAM2K8qWotKW:kXkcr2qgrWcabr5SAzqVUeqXTjBVYvPdxO4PwN7c9mMydY:6JUtM9y5klXNb8hgSOCtQRFiQIRXXMywKtCmZ03OlWF_dT9P2ke8ncwEt4BJQsdUYfr7cfnHir20zouyTANqg1MvUdHcw3n8PDxynYhlFNmAa53Sc1rz5oBDhR6uKgzLMx9Cck3pi0Voh_4DfKZLrLh21EIqoECe27_VOvJU8YJVvA:vNAGxyvAnRQZNaMTlYtsjIo2eigbWml2:4bLCIUOyec8KojjZZc98kNaOsV9LWuIER7qqYEkeTq6QXTWIfCdvdw86k2_EKypDdoBHPxzkp9RQB0qJFgwwEJoDBNb6LS:HIXw6zpnxAVA47I_BDjUH3pmYaVyGAww8OA9CgOX4gsG3Ermo_0Xle3PMKCAiUIr5eA8PjMXcAUDkkNlnlB1QUXVfr4zi5Jb6vq:DD0UWw5qbsghbKRXKXsNqhwjjDLw1gXnBDv_moO15HHfhVwtpUciUY1rEHXnXgBEoOfFGA4dgLJMb55KmNq2hjqSIp:CAPKQKR4Nt2NKrmxCONl_tYzzwiRDVnUMRNgYmPrUfrOedwBcqXDXedOSFlk0KNnpA9NlaJTuvHtxtQkVCTBllLRGhhCDEUh4ugwZx4gGv:Vz7hMlRAF0BCoRb08xkPcWIbhXQGT8_kAb:pIokkX3O2rSGa6YR7M3eJ5ItjDHf0UqibA:fozpU8k5k0oE9s3_G1sNBP6tqyVVlp7_yLloQJ5oUdZLwXHYgolxhUulD:I2:3M9xjxVfvQRvVwrPTC2:XrfP56Ogh:CSUuB:ekt4tfIbbcz4z2A5Gh:U8i8Zy9rkE_xevRBUrZOlV89XZP5tOYgI27gJOgoAIV64jTH53WKJJQul6JoDtp9LTqYU26aYldEpXLEPjZpLFgmF3nNVhksC8dqCsSRxIb0G9wTCfgiOnTTcapmoA54KRFm3ZXAKmedNZ_w:It5ViSVF2iiMv9A6HXaMBAseR07e_4SewbVZPkENSQY_TT0CN1QCdcaScvAoCaCHxCJ5RWg:X9jI9QyEI5fPuxtsGjkeV2Zom8qlvJnaHhJXpbY6EtmhhL71jgaMXzwFdRzPlnEYJzn_Q4kFoNwiFIUiVI99xdNYcNmvPxXL_pAhVN5IdzWhRvuxqXIuOoig9a28wyhshWvXyCDkVJxqJ0lqrcsuYlZMsGWDaINlvZYjtI2WuekJHAwMnilJR6:D_zrQzrLTcQjl18Oa8_xzNXP5ohWRrtb7JdNokUjqvmJQDbqn:5FalWh9432tblcNRpr2A3Lr9C6gCDww:U_z7MTbZSkqVa0UU8SLZsAJ5vg5O_jDgH9Ocqv3SgJx2LGm6prHA1GjT8HdcSqJqfVp7ke9_3od_vZnKnYmgagIbqf07xkBdwn1cvVV9bvob8_RB54b5Osd8VTGAKWElk6Lw0CWmtx2UTVAEhqfBp8gjSkjEvBWBj6IIILq5xOXJ7RCWTuigt1eeXwaCwmYlPp_RG2hPZH8_LTAEtEarvAMPgCUUK9DsDMjvvaLzidt8s2T9N_H2o9V5bFyJSlrakUDKCnWKAY2Wra_5iAe0XSzCZ4Eua2aSY4aU7mOa2EcaF2gbw:1m8nRpE9S3:Lzmm1aiPLAeQMWAFl9_QuathRsB1RhAxcc_lZbKLyg3jZm3yaQckPTjU8xrVRsnVY2IPnhUbd_rLZgyEmgTo7880R:aAjCJR5XKwzM0jQ:vmawkUWM2aqDItNoqqQvvNwdq3C0HlA6XkVszVShF0_7Ai9bh8eekPA2FydU3Nsm9c71E3j_S9SlvqFwwxq1ExORQiaJCZxFcR7ys1jaQyNZWYGEP2Nsh51sCjVzP:15wTTwxqUoQOezWritLgeKkY8lcgmXku_ozHuXwQf0Wx3BTKN1Z61c9X3w6Usj72F0qNR:SxL6:kDeyfJl8yHQbYuS1W5hqkbN3iUFToHR1coSb:BNuxg:9nP4U2iMvHE1lpx6M5qzkDURW6o2J3ZT6z076VeZp2kfqMoLHRswZ4uAkzPqgSKEhWrryycGH53z3pGap5jmU8lUZbqDMW1KvPfEm5rfu7LH8zSx0gahrfrENBJ6hasmHqyf1JuD0oBPdkV:ffLBHmJfSkmgTRdJBr47cb_JfaaXFzsZL6T8Z9:lky1Vt9ivL3lIqYhAPFUITYi3Rf2w_RzxX:YlQhExxa:I8FXIO58XmRLxKTdndpCENxOXMGAnQLEukjdrWXdf4ywnLkWTjJ0TFK7O0zHpXUfLD_zFW:_VWEn2FfDFoWDhr5u_St5D8W2qsP7OKsq9sBRctHcmGWQUVBQygzEebpoNfNdU8lQUUSi_A2ZX0Dm9p7zj3D6RrpvO0AtYlzUdD2GTURatMvuEbrZtggyCo2_XgdpQTbk7ETwQA2z7ErbpXzTC3dzqsG8gfAu8HDRrvFW43H8Yi2zZD34M4BhjU4Qflo6n6K5jfYGSktI7MqFHcZ5P9GkAWOzLKMTV1E4nSmTrA0aM_D4AWG6zX2qlsZ8X4cB_I7pEyaR0AYc2wtzAQ:R3wmZF8WvHoGasOMMmVP8vxCimI3lOJFk9avkMMmzUGan6uy2GLkGEUHHOwmqIb74bEtkkzP5eR:3v_JT4xIyofFiPrO4fVk78_P6j00fvnTHW6_0LHZiA4VwG:o:xWo5Z7s3AQK21If2s1e1HinfNOi09NdyScD6d3eTli:tH_HadIHcY8bdcOo2Tpn5SycRTq_oFM86XidBJO8RGlOuJLS8xJVREHUkNgx7M8d1_MJvluc7dbliKGrv1ruWypk4BuT7kdMvuTCCK_5txZJZ07V9uoWy:r77MexliUlPfBckb7Kkkf2JGgDJDGwFTo:4PbSgBWBAL0QDJ0EloSiUDw6ba4B4w8S7zn6Cksa:XOoRYJ78DyeO4w8dqqvzwMZQ3Qa:E8dwHESWwPMvpVT:zBAjQ01lKpBl985oNM9yUWm:_vyfPLoJAkNGkeoqML:5bQxolzy4e7ZNr:J85xMzkbziltQ4bRo68QT_o0Leu9PX09_LKHVjE8Pwc9m8t0k_XpwZDOv30oPMwZ2eGiwoJSprFLbzOgz5XdaPn6osGsnqhKtZZ7AigSltpnpcOCVDFK6JPunXSKVlwEoAHmZFNHzz1r1qBfB8vZZoqoW4Jkpc_IWkCgqd5CKWBVolfZ:oPOXo8XryjbXTrikeq04_ONAB6aQJJnonvyl_4DCKzx370lxDnc1U8AOfZUmNXskiy9WZRbSx5K3SwfF8jRmPbkocU2bckGzpyXMP7t3YT4tAhs6lAyaVKkka_Epzk6VR2wCJF90rHoXbsONIiVP4fhCkek3l5ZFk8bfkMNizUGrj6uzYWLkKFUHJO2mqJb74aEtkkyP5eRV3v_JT4xIyofFiPrO4fVk78_P6n00funTHW__0LHJiA4VwG:o9xWo9XBs3EOe20_T2sW2vHiApNOjr9NdyScD6XxeTo6FtGIjadNtIY7wjcOntTpndSyREFW_NQuCWSuRBADolGm:EJLxzxdZrFHx:vNxctoJ7J6lqYHWBxgCc1WQW95ikjFZnP09c:XcBjX1DDlk3t009KRuACgSIVbcovKhY5DVNzh7l4kxUocXTWwMevOkN9EgjzH8:Qa:u5aJCAhoVkRfSngaGiWhegSvcjTQL1cKXUChQlCRyzv5QOggIyyi2g3y1NkrubSNmwQLXT22XlYq9jkGOICiK1EGuTDO142zgzef7fkiH54ZHBlDbkKZ:NKeMrkw1uj4MZp7NQGYC5kBFkaJRltxxbQ1LTkSfDLfAGjXXpUVfK8IpE9t1c9Xvt1XTHpxio4vPaoPMTJ2eGvwoJT1rFL82OhIMXdbsr6omxsnq84tZZRQigTZtpnZeOCVrFK6JLunXVKVlMsoAHmdFNHPz0XTwyfRWvWZ_CoW0GkpnoUWkGgGdkSuWcxwn2dpcPOb_WXDukbYUHejiC0iYyxQDIyYLt9_bwy7o4EqOzxe4elurbc1ImQydR2uNbI6iADadRdaB5qCVMgnqfRbJX6_N2Uze6qPdkrwz0bB_Um4z3DONwv9Lu64LMgw26lK0K2TOaVydw6AcP31oeYuY12MVDYkKkcKvUI0X51Khzu6fbllEa43UCVBgPwX:GaaNs_sXvkjNZFh3UHYn4kpoYoN3DhbJlOsBcJEh3zMP7p2b3mLo:C4tYE_E1uv_CUIL5qiUwYXsZDaydHONTTnettoupW:FUhFJZgXkpOnzKZGxY9w3jNUyykR9Q0ieNfZrpBxcJxQ7o4FGDxTSZxgftJbWes4jERJuGG5A352nU60y3AW3YKPuwP09hpW84zW4OJ:nmGQOXiIvQNU7VzhTFrXGH7:qu7LQP:9vyIXnLecJ7Xlm8SpR6r3IXtX7uHYVhyh_AmYMWsG4tTwLUy_8BCFOl:xXMyw:noUdtwnRZ8a2pHO1nsDGCzwbPf2QGMonXCeQTPltR_BRhm1mwVQca2FrnOrKlDOvsJFjNkq5::bbwtWw1BxYx7jlME9RAZOq82brZLKpF11d0CAw1YO:Q7Uj7oWmHr7tE6xlGv:QlvX1LimbMhR3p7RSRM_MHlKvaDTOTl8dDJtUbArO08IGU2nMrcvssPzSJa58E70uHJypJQaI9WZ1Bx7nPQSYIZa5F6fvve9EsySL1N6ebQeReQUKemlP610lJNxf57D64tsqAnalWASZ7VeRqu7K2NKopRfDTw9myfd34dz9KZuXh:IoTS2amv3lBxth:qwPmqRbPuzQ3bB0Q9LiuwG8zlqKDb9figczu4pk1Z6QtNfTGT8H8n0HoDiAMY7ePTvOCQ5t1E3dbwW6bG4Rgbea9KPCSLs8W3PKlezyecjt1CtMB5DcRnZBK2fUq5K0CikgHpNRROZmFS7:rq3nfldwCyvR8ckSiLwWbD8tbKSxEFqMuAaegwlJ6QMg0bmBY8kDEVQE8zYBdI_FDINzGIunwiZr1DodK_r4kdkOTnxSqs_z4IJBWkAnwsfdB60j2qsBlvOZ0bkfcMpozV7rkgKhLRXtrTDK:kTsi7i4On0v1SSsp6Y4G0fCZfPHT_Nnb1VQq5sHGGPO_rBWsv7Oe5Iqz_p9ob8Upw0af4ilX7TsDL2gfyTXVpoFiqp4K0I2B9G2LB0jt2IsDmdF4yl5YFd7ZYC9My0SkTBtXZ4:cIuLo9cvDypDI3nZZOI:y:oUhtyY3fAKxWjmCglc8vzxyZ_hbkpg7JAQ0JqHlfrb1aBgfkABi0V6GBhNXqwtezMd:FAR4_vRJnHG6qTfJf6tx7G8DAIH4dittG2ps1ObmNyI3GfrFWqAcBqXs4YKrpAlhiw5YsPMUQhuJjXlJG0Z:JDsOkHUfZmrwo9CMhbq:9hdW3_ooIZ1gzki9ufndLIqHyPSoVLyGAKdyrGxecQCUAEvQYfZ4wujaZ_Bg9tbm3PQkGvaLpcwvU40A7q1YcnfzPcArtZg9Rx6oQ2CmwN:G6pVZz8hoDln1wT47yo5sbUPuAEjf:n2pC:Ii3ScNMLvH_XoB7fb5p0c9G3sl:JyJMS:1G6ND5Y7jgmM00n6B7mrKlNxl1xDJZZQ2bojx_3BLm49_AT3VxYbibelam20g:gX:tU7RJbFjZCCursca9jA5XSwpjC5Qh28aRU6eBn_AmwdaV2U1HMmkQk6XeVNCHfMPhiPeH0yhCCDhh1EfUhMS4GOpFmncmdYFD0I3glfo7IT1Ipto1rR_hzKEkwUk2mkJH5XLOMWsR70Y:sPJ53yME87Y56zxp7N5tSfvcvC2Dlm63YswfxlQQnV_eifsHDGZmOgBoErLcF:AClI0k9mYdYIcKVhpbqhjo7f4cil2ZeAomFuLDQ7H29SNKOHFPERjuKeMHsHQ:GGAkknnBJo5a1klqwsitIwKk1Tzon8oujh1WUZVJj8eTb1jX2mPztAR_:zqqyY8lAbTZeAkah3NTBzUQrv7m59h1yI982ioHwSrr2RKPCz:lT3IsUR1jfVB0sdSZchV3XP9etb3ulA8DAQIs9cDsvXmIc6xaeopCMA1gLy:4gZUPR9dFXiNgH7:R6QDxDVggAq2OfqJ04JwJiHz24HlYaGLjIyHiBg45yOSo26hcJOKIs43_nhF8AKf82AuoE2YiKGUBQHxv1PDblWPbDj4l2ERspysZHx2kno7svxkFrMbNLWnQcJdwKkAO7tGd_k:TJ_j3HebehsJyD:UTyi73TZZbiGuFZXdnmNtVZKKHImrlDQXS_e_xdIodKDZZXvVRbE93vckBqM471XdnukmfZVof0yEJ3n7hXODTquOv7dOso6:nXlr1_k0NNE5pHxPZynSLs22sxCqQfViHSbPXhIKV0Sq8Prcy6i2Q64A5Y9sNPje4c_hVgm5tTPTIuKkGpr09Vc3R97c9IfvOV0NvNE3NxnSCbAO3CyO8fRUA7WH8WPY:2e1uNY6Tp3Wwlde75PN:sac:MU9F2CEBFAbEPUvXix3o34U8dM47UNwg18Ubqq7ByFr2MrvQf65PmjnYaBfTm8i6Ov8RHhAxevQc7QLI_iZ9uRKO8aRkV7hcZ:jLxPWshfuIA9XG2NuQxMho7XJsCYk4cvgE7pKOrE_nJHn3SA4w0K2K2eFqUderz7dTzbG4mrC3F8HlCC_P4eYMFAkzv_zB9KJ73ahJt5MsnOxbOxnExz7bbQ48OYsaR15eo9Mwjcw4cqB9LctHVKJih7yxZFHvuRYqouF779cgurWHzJUQMqaJ:82DtHdO_joDUQDAzJdmPF:vluNKZgX8S9EU5i5mWcTrOg6eG6rB8BtBtUkiyBcwHlsCl54LRSOUki_vX1ZHHM_gGOm21aguilhvWcDVpZSOKjBEwDOMlYMa33_ux_uZBNtzAAT_TVsiN08H3QBtFZSdmHeLv9ni9d1E6E22I:jNwPnuTodzqlW:bWvR4itymAYJVKB7f5z8H1CecmJJLw_ltbqvTEKlFBBZfnHyhY6W7z7y5vX1SrshZ695e:wHsbNr38tXCC:Mn32qA:AdOdUcJbUhusTJnFnLhv9Fp:v9GzXI09uAd7YXKsOQcW8Wz3j8ZXTvR8rBozKPNx33xV0RCzAD9T1xBh7za8Mo9vdK2NL89i3nyxyxrcwZqyHBgE_dDglmgZt:_z0Sr633HnwJBORDfwnWvyH4LVNP7wy37lvxLugaQOwLwmCnsgSgsPPGwUQtk83mxTdOZpTTZ0Q3mXWX0yDSElvIKF46rsNV1JgOYap:bPf7G32ni4zU3vaRyTLW1rV5BJttTQSkt9dXu8e6NLqjLLYoHHURJq1gJFYM3ZCGCfpnzHlfFyaqJ0qH6mD2mo_sd2lpfmiCkaKvLa2osSJ7AZ_RAY:oMSdF3ijULsjw5mRHRY:ahMxKj0hiWBCQONGxXKU1elBdoOhQ2isSPIKofvl6cQbdZjW4tQR0je5rDvPNzouru5GmSvEZ9CKjxgu_9Qm:UUdw3bXHorNJ2hYQV5k:heuC0AQEUtRapzWJJc7I1dDs0eVqPDT4:apu6QXXDOA1uUOPS6NE4gL8zXLOyeVpQ6Il1SHRI0lL7SitnUPQcXGcmpu7lnN:at6O3NcV4yS9G1AhbPfIOknUH0MrhtBDYIybSjw5o2G1tFXrn74NOXErXzDqynXPYp2V8Q8IJuNh9B:iMdL0VIB9h7mdmL1WlTMLyDGenxJSU3uvYxZUxPQk4MfN6vhviGT_n0Y721I51b0V9VFsASsuvtpFNmfIvAaUcsIH2lZPzZ0vC8rMGkV6aTV00fzzTZql:3PPZzssrDfIrzxGHUySxXocZ0rbEQDXoCMsF:cUhgToOfRX7t0qYB:O:RTdSB7yvYkb9XeEYjoKaygTJvYUE77Qw14kDGMsXfAxtYafTLLHsmqNxEdzXMYnafkVOSTjN0aOOnHW2AvlD0CBAB:MjA7N0pUD0d3A6c1_Y_67VpqUPUXqybDPs5ZfEL68YOMh:ytkho5I5vXsfH0QyeZ5iHNQUtA2h:eivThJ4afYEwmQihoylfxfE70Cf2oJVjvFv6uu3fOWBq1qErBgv:rtWatksiclldWO263YPCI845DfwommLeQGQPYHfZkz9Aef7tLgCldXkZNH8f_LbxG2tu776_j3Dvyjfdcm:xeKdAfBDE4BzLCK59fe8gr1giqKzkzXiYylkjb26qtG:9_RIEpMwSf0aJb7Cq:f1cBsCtGkwFwA:4q74gBjMAL_10J02LRSkmNc7qDYB4SOS70hUCi:n:XRDcYJ2Y4zfjka_wKin:52YJYraNpPyb1d5jx0vYD:BqauD:mrfGUKQyjIcMUcpW9rpqxzyBplUhHzB12D1RDDsld1RhNyY6_:VBlvMl6bnB:esCyRuWd7k5:U5UzNWcM91Gd46e586_IlBpC2Z9PGSNDHInvfAOZCZlsH_oFiFlHsnxDkFYSASIXb4vbOAEtcQCWVhBlHLlDcOZGYswwO:Mf9UptoX7hxcQH4hmysQoWaT1zieId2GydRa10yMfB:MHfpKm:00x6CoCXvm9uS4J4yk0vZX0tTq4fIPLTabaBriwlz82NvaWYpJvCPo_qdWZzUx1AkICneb:HRDTX7ycoCz8IwmgibQQrdl4r3v5qRiSLM6HBa_EStcFS0MSDaSbaypc3d4ptYE1eAwUE6_BgJyh4F2A9JrwIva3JQnvVI485IBkKiTEcFoDPjD:P25GZcaGWBcqcG96aynVXwYcejGNUFib9EDOxvJGz9CjieEtOzfWM0Y5:6s_p0F21mRX74UjljPEPj0ztTJ7w9_Q1UlRgUIX2Il2N0qzodkceu9WLdcG4RMyj2Pc4rSjUGsbVzmA9_9NAB0JG_LRrWakR5YH4ZgJ4buQ_miGBkOrzcI6bcjKukapbjO5SywvyIP9CbhvpJDlLseZ86ehU4tef1_J9o9Wm3blnwhcCCsojrdWijHsu9rJOjFOaXxHdi1_9J_v6puBxaM8nzpdOF9FVKnmT3ByTqtEtznFk:8gyfmXHH:oxN9EaCbT_irh5UYYMfID5KAR2i:V:hmuUlBna24hJypA_gXcAkd3R2W5ldqfGcmaCHRgZv3AQ:W_SQsDQsHjrBs39R3PtwJR2G0jTlI1G2ONFejMbsiqmztImDzaHpXZWYa_r8aXmjnh1p2_U4ZPCR7yCwL8pa3pfeDypSsS0cKWR9D5dgUvKugFAMl_b4C3z1Aljbg6LrW1VKODNmksqsOFCTSvRF2JHZmg6zZP0IQX7fpQ2azSRwArInV:1hMhBP1tgZFG:DYZi_:aSnJkwmTp902wzZhCblTH6SzjbIWlsymQi74bWn3wsSdWnvDyGU5JpRm5ltmdGnq0BSUajIUEmEt_QKqcondHjw_NprMY1eVcV0kQYByORa0LZrhIupSCJz9TY4NtAlN6naY5NZiTR6aGZeyVxVWcPFzLUYrsCLhWTCmPvPRX5:1irmZDYyTE0kR1WS7MA72Zyf0SFanejCsBi3MvGdNZARahFgpp1ia0Q47aYN:kpZJuRsOOkGyrCs2H1uvQkCMdWhQUzCfPDfQdad1x3dR:1lLNi_QaK_g2M:K9wZ114_Qm7wmOhlqn:F9fHKwBkzLXPh:xJ9dBs4PCf3n:tkyIyi9iccrAcbw4KWo9S2B9gc9hVyULVD2s00E__OCHTtKjtzvtPb5ZcDyinL0ydUluYlDV6Q2a4AF0YtXm2NxYM27G2sCmBOyla5:rOnfSSw9ScdtWihqnbjywLNinxlJC6_DsW2JikbqYzlCv7OHtMCc129h1B3UnOqWNUMgrn8ni0g7ZRZv93mSi2hYOvd8IsELXhjvqJw1HhJcwG3qVw0eMhXATwg2gLnXMM:srRogSkuZ8:8ijdoq9T_53Qry2jXsqAvFQeC0D99Os6lQhhr1YpdJkgILWporbEx1lrvpGC3mnLTegJ6wA00lEEK2V98Z:mWgNfzT4SHUXBnB5ef1SNbFCshn_h7r8skWdIUuM3PGeOIRsJqV1uBqKE7aLif8jggvAN0jCARBI45J8YadiuHR_qpopYlPdQPgDyoX1WoIhZ5MUt4ZMLxbBqkbRfB9rlFbCqwc095tTCY_ifhN9o6cbSyVBPNB731nW:eWfwqidmvCgaiEYSVw8dBoDVBOQZ3NrQnm33ASa7ZYgwd9yoi_ORDDcCPkuHry9_b6VhopSftL8X8EUD9QRN_MrMUOx9RUzzwdXCgbz28vxwPe3UNLtRcRkPqfIPNlaCmElXe6:MND5h5OkUDEjL2LGtEqOfiyhJ2MIBHdATNyRMbyKFR0SKZQeKpe6K_FgRUvNwwYWsSanX9m:0Nx2yIe0iZHKyutxe8Nwj:PE_7Id3cbWxkzl1XrYonc1Cw52r1wTO1nPrDmaWPIC9DXFn3cT_:GloZcAf5C1yVT1V9J1xwbQUOLBbu5We4ciCje_HoPRdNJWCsqnWdAA9YQJnO01:2V9wXHNJ50rU4SwmiSJHt0N9il3dCoCf46d5EYUSZm4:DvZhePXaR8jm_MYfzo4YUUEyO1VKR:HYQKyipXxqxOsKsfO5iGiEslaKc5_l5nqTd:2KytzwOLDh:lvuB1oySOrGatFEW8RmjBbl_9ArdgXTOJbR81li5Sq5qlpOzNOpnQmIITFIQuy1uAHBp8E1t5PYUtrBIhdHaqQBOAbHc5XxOb6D9GSjbpemrvOdGCFPTpZevTP99YKZnM02wg1OEuNhWScxXU34ZkPTHuzcyK_mVk7pqgWgbc:tFq037DFs_2tSs5ohsqWpYclPIDwUceGIMmtQPlshjQ:XV:9oQDOPgjNfaieO_g42J32_mtKwDQiIA86JOAVq8FGqF_DUOPRX1Is6K3VBkjihSIJP9tg4LJ4hnMPvBRQqE1JY2b2BNeHvxx0iWxmcPym1:dr2hVMJU:Yo2kq5xv7cBgG8PHNAvHSfmkekT6FOrMS9n66xAVD_rX_Jvmo2J63FQw22YiYwUKvLpGtF3Wd1Sgw_6hBsUD71rWRxTtrzpD:WEs7oT0jCyVJbFrdnmX0mxWU7cfjnIrjqantKHBtDRh6evNQor5eQLljdbd29lnMnsBErwh:awbjnTkYOLIRghEDf9bULo2dA3dOaohitPYoGVn1rF15tyQUdRU:cyJN2FNGp5Ki6FSxQkeC5EjHe6QA4yCMJZ0q_nr5JuPHOKzalhSwcQKv147IBhOEqd_mcnAqbK77dOiy8UA7AwD1flY3KT9NB:KsX2A6VPbD8I:gxE3sSMgURHUfy1ZkLsOUFbgFSFzB9bHdsdM3TcwDIjp5PA:BrWEVc5ZXWJ:5tEu8HKQGFtvIkkqxIhnC:62mjoFfueM7MGlDl9FuRN_1LIEZB5q6te4gIGN6hJFyLMvl36o:_0gedSpbH56sO81UScO7lChXinVy0ady27tFutL5wDfuvBWDcNa_1UgvK:LEA7SDG_VnvzDIvABCgpbTwYdWu4rzXpVhdKpDLXpd4pvVAu90mdlgaKBiOLDVJIz0IIMQvOaayEtFfdmtwzGzaB7xHV2R5YNn_c7DscwewLNTxTs6FpY0vYvUP3du7xEAEiJ:JF4n:XH5V334l0m2eW3emIlC1Bv7k8mkHDfT0_liZyiEKQjARlq4IELf4RHIJc_lDi9T_WWXvLwvEoj9bsoD0mupHCOgZXS6xPr1CCW0nhoXxqcGh0jfLQlcYPZokR9rbvT4Wg46riXOAnQxeI8:v9qH:KOetpmgOSm1L1I20DZNAVy7HMt:FJb4TEqGQauJBtvIMQWSNp50mLFavW_985l9YV:T3dLewc5gwbXOtQIPikcXK2a2lNbqFEEvKid_F:DeptzrVht8I2qMEGqgyiDJea4rf:syUKaXfSbX_37uFKHUL4Pel7QK0m38I1vevzpx22DIBkqGptlvfGdXuFcyt:MFCHp:dZ:SdjKtVOpXWYNG7eqOcknKFfGWCiAaQfEEenL9qClOsldGtYqRTVbfJtHgx72rfwAZ_aUL_Jg7w2OM3TcdATTE8pUcRqb27dDmIdRkbAbFQpioDQDGnw1a9PgdsFv2To5:h5WAREUHV31GCKIHqhom0jeo2Ki_:tZ6mku8pqaa
;

create or replace procedure sudoku.sudoku_eliminate()  WRAPPED SQL10012 ablGWmdiWmtqTmdmTmtKTmtuUndGUmdeUmJiWntGYidaWmdaWmdm4mdzUzcaGicaGdrv1rzhmCjMXVWx92O4uw_j9nR8Stv8UjBtjbqD2VBfIbz3cBtE0WKpv4GYEWLMKSRZdk28_3qSmhRnKJ3LIbqSmzoQCSbyLO2xLlWWMeqzRu3bHZMbIaubcy6kuLcSW0_KreS4HLFEJspBxbBbE_SuSIgAbc:eAYAjL:5mnfJlMAxLzAsHpmKWQxKMLEo2KdcOlj7eLUsZDESLdWtqenvfBq63a3nSGGQ7nf8mVTp_XqmpCRbqwC2f7hCajspALNAn7wEm8EoUxhaQeb_tuNiU46wsBwYKt7pvT8GDvn0PKmfSMAmDjr6jPzX1ubaM:XjcNCiFZll7MKfJl:4d3SoYc1z4ZRPR7DWE7Bwxlxarf4NWKUeUaJgUGRjGtsJlaHjuxJAov4:Rq:igwTh7_9GUB39IVYSFGhUAkmU4x_eMCEi9QcX2b9NhEL2DkQ4GyM9p55n6ACXp_:af8E4qRKUfh:HJ4XN3snO13YGEusUfITgQc_WdBOgoV1zOldIUWQyL7vsEaiDzj71x280CZrg4tk9nWZc:StO0ozi_mTsd:48zt0dvg0KmNVO:zcL68Wzh6uSVswn6OPNI9_ug6ggkwojChZvpSyRdcyv9gUpGPj9snGp6DAzhWsFlhqkPERlpuOJD_HX8xxVb3rzkQ7VhpGMv2q4WAcnU12f63uTeR0Nk4hKoA62p0NMO_yVKmEdySSeevDXuGzXi2IoXliz8Iq:Vnhhi3SCaDsMob0jjdOFJH2BoWrjpdnA2AIr8J5Pt9aG:IrxzUGted:A3oOCg7XjYgBOU7Pa6UBXg3la596fPVm6FP4TcbHXolKPZoO9:cI:l6H:_hM_UGp1d6VNctZvPd9OI5JMp3vyKpEDEYl1N3YuAYwIospl1h9uz1ZKcSfos:EF7FN1MxpyECTQF12eLoA_d3RbPcaa2GPkn:G4IdLbsuyZE4q_CFoym5:sUzvgeJTDjla9oGJD54zliuo_Gj7sjVGJ04kxuTzrCasevGbABGRy6sWIxMX7GxfQnrIU81YO3pxksT75R5hp_AAin:UwA3n1Hgug3GYyrdG6BO3DKzzR9RcF1jliy7Sqonybsp:d9JRnaFghEnqbMUBhxNnaWajqcqQJcdX2qq4kykKtHnBL0_qUx1nn4HDrlfw0gdTArT89Rx01CxyWHHaRAquz595CF8oHBczu9XQHfVmuyP6MyjJbfrM4teXU_EHAOpb9BfFhs:4Gi8fgnqyzqzWqBq54sBWb_pPR9Q:4BDE:6wqT26iqZlwvggLENIMODJcUUNqYRl5uIuSdQ02ObxDTkb:vVkHxxVQPCgISBYV9ZqdkVZinaUerBMjEwlkryBQrXYCS19WVFkijsLvElRrFCJczzzq6FGRhdeJ8afpdzKTrzeLrZzK8242:U2qQj7Aj7bd0JSZW14fw4xEE9T6f8WbYdXFCK6fvxJeZu0bMRkSG6J1MI:xSXTtFR8yOnkmdt0l0iCWgzoEbuNgRpLcrCvezwjWUlYPOYr0ThPfRCZV5CtNZBCZVXA87TX6090dHmIvc4ZjIHl6fGKM3MTn_ruiAji1ZDCT90xFjF965B7PRBBHSTA89ksVG:lWbY_5R9RNCQFhLtDqtR_yxnRxqqCzFsq8rDsW0u3CUnL6Lcc4IxYWOuEl4VDXwkJXzqhcQ:WBM7oGwo8ubtzoAhoXtyfMPebSTpyH0E8REKZKpGcCTHHe63yfESM5yy5vHA8ziSLNaVLVqDzygGUq88Gty7Tty:YcoQZskcl3sYa:ybCF_44fPWPzyVMArBBgxsx1EGv_BgbmXI8JJJD4ebZ9LhfDGtsSuwYMKr4KU533lfJYTKx6RVa30zVKUIOkPO2itpOwuWtz4qp8FrGGJGCj4fs5EpCZszA57ygly:tIrx:BNQitFTBRiPDUWEr_f3tGJy8OECvgJemWLHURMN0X2aGySGujGQf6bKIPzT82b8bcxXXF:HjBx557aHnzd20HcjIXoTrnBeNOU5rW1aiKPNcR4U:It6UFQyEJL7phaD3RM0yXZWm4S1KHKROlDchiqU_P1nKmi5RoFXigrb0MFtce9OEXoRHYOw1L6VPhLf6McemUZ4f701S3IM0pCuxbukRncv_OOJlSQJRKOiJlSUEBtA7UwrBi3aipKaeaOWmrEnHzxbCecacRF1jPbn1YHj3ekz3BRdcin_VabYVkBwYyrSFz2JS:dKgN5Llv:4eRPeK2IprjQLt_vmj7I3aLZPo47SAUblNr2teBSGs3c6r3V1QXDn0mT_8grk8lQ:CE8cVcf6NnzdU4q:gc1gRMFi5ZUUxpneFa6rYBvaDEtskYdHEJAfeWREjzlhsOdPu3e5L8Oc0kNVuzrfJ4XwvsZvN_JWw84NpkkNNw54YlpV3gdjIyDeCpd3YmbXpQoFSC4sdbOIR3lQlc:nV4Q5aoJdkkv5rYywVT:BA2UL6QTz7F2p5jeXowv0:jZSXtWMQc3ZpiInxVq1b3YMGOEehuGBbj3iMioPihiuLpfkufxZE4EsoUZPF90Pym5ivYL:mbx:SjA9:mby9Fv2rssc2XkXzLQFdVhLvPLv11j:Oc97yiF_:4WD_FWWNxHzIj2YisqpHj02pjb20Vbd2uNgotpOu7tJA8eQv7Is2WP0tbP:q0BUV8CDJoN_JcL4E7EwMwOBjl82I9b_Fl1h7SJZ_j7roKvdh1I4C7q48I:BXt5Tzzpp41Wzcm9XLlv_Pcg_qOr3:1IJ7t9KSuoRDyUmd0qMcCpfQy9kGFlpugqCd4oxt2JC2JDubt:79m2oosaiC8M55RsPGyWv8fsIXCnfUrb20bYn1bobQUmbkMcsbQUatHIOzHQuC5PUfF4p3jb5Zhw0AF1Cf:iceKKpxHCMp3PBPR:62mFVs2DU1QXhta2ZgXEKYLQOvh_7enJpoYYIDTGI0LUVYgTSTsoVSn6mVmf2ddXa6laYPxM7qFGW2:eNKBKMRitIRkt1CWK1CfoFobzcRBdtFdgbt3Bry6S9n4IAGoiXsaLsUuxtnmd9QPwvSl0qaFd20GcaoLo9o1PnV5FaaIFGvT59U1IR8AjqsFb:4zXfXAoyIg4icBWBmSggoL1WN6T2ehNRUQMKF_AaTCiKns9MKTl7Yi0CQxWYfymbHPqoLUsUAOvJPYnBQfRyKCD9PrLp8ElG2JH2y345D46i_JpW5l4zlAa:u6hw6MJrwLUPBVlbNjnu4uTdruj7w4CpE4WEV_KnIW58G3h_kaLgGiQRFstCC:kLjW0py5RiWQ4:qMDOuY7zHRVHyc3O64k1OAqi1isDRw09cl2sLOWQf10A:OPZfq0pFL7c3:9dF24Q9pXvqfNzZnH9CDuJ8SgJUpgqQcwC7xgGlXYKgYvLW6UFKhGOjwEYP7TPUkZJMuaTkRGvTwcvnEi4a1g_TWOe:Ez_1AgRRLujkVowK8zhbNjYg28_7T8U_a16:BB47YWIETYZ_A1IBbPEJSAEuiIOE0Y0rTTLFzzAWiJ8YbLPFDLA0Wbd0CSJpyKQVStLQ3jivvzYgYBZ1RhXcqZWJIArXfE8SCnEmsrY7zY55gKCBDHsjeahuLzwt04V32OFU1:l1nbO7mhLuxbqW5mJCCXlUTbNoC0q651mTMo9HQOOnZ_UL575:uYCWqPaqCyJKiv:RAAvq0yz88qFjn33t4qHYHHcTs4jIWIAIvIH5YuSn6tpLINHajQHSVYT0b0uiwcC2jAJiJ4VKR0cIl2I7wb0ks_hX5A2cKiVjFP1xVE57NrT0o8doevlERi3RSGh9HmfYNnwI8QpdNSnAMT_R6_6YlxiVBsOAw00kt22Lr03dnw_kUfu8Q2ZbqHZoXlDVVA3vEX5uyhiHbrPibjtPOjltjr_c8unVOPm6_H_jQtpQXTL_FQ7DDuT2SqcOe1aJIdPW9YnkcGnQkTEmdrlKPFZkoYPwKg8cDRbpsTin5lDHGtLqvOuRHi_rziAY9rpX15X0nhykKXDK91F4aLInDCxsTLQQN2aUGRvj3hJniqQsqRkx_n995I:9DXG:Dv84wqCWRYxOAKMncCR2TERSd1jIjRh5cvdEJIP83AIIh8xmpkINSx8Fs3WS34vumVN2DfgyaGCFK3n64gn9AKXzqqJW2nM2c8dRMNUVhsjzS0CgXxgzQSbqWG_aXSs:3O6T2lB6VXlButl7Cz9lBuB8RcZstqqZYBDNvQxBbnLvb7a3A3DvOhrB51rf7b3rLZm98BCtUJlMy1wudjQdKlpG6Smcr36jWiPDPEd4wLH6HJSv6NO54HfLzWJHfeZRbnbSYYtWNwcAcuc6BR3lvg80RnHyu36KTmSmWzFNLf7rjtE1rpapqn9XVn7Oyg7ACqmgUWDQg4tHlFgpwxrMLCftBTAiYqllHRrJV_phCTH2ApGzbKfG5CNdoLRI2wYIh_LmNZ_D9IMDJ0JV6OoVpI_1lhLUeWHOpFrSavMvdivwO6uIKdeTb8v_jBQeFuD:3xuMeBLvrblKsNUdiIe_JhWekV1jZt5qUPvkCjo1kHz6lNOFwK98:pd0tKDcxkYSUaZCW8T:TdtJvKkcoUVFNgPW3_rGvV8WsoEie2se7_i9pmert4hbKlVoKS5E_VB0TK_uMnmqxZFSVb7m1tRdS:rPW1PGmOc5aqlVZIiU9AMOwCtgEOcJMcFhw_vwI_mL2_2mvQIeX1M7FtJxclf33BSnySjSTaUjmLeRQrj5E07IOs2wGr47M9ZbrU:ZHjS:tPg7h26XRAa7M4aB_i2v3LnlLSsa4:6BSHUH7Dn3Kr5IMMHcS_eG2GSfa_ISLi8Im:tHtfAgjmC9_oCD2eOC9_gR835lohXSOtjCtnvxj5rhbV9Plfv9jdhxDbbh3vdbNU0IRVpnuDd1akccBZXlPrHZ:LZHthNZbBnz02RDnoT_B5OldKEHUlwFCMmgTNbaLLKrlVj5O:UbliJYrCYQEijpCgE461uEfYWHldLC4EmVISmpQSgnk8OliE54R0OSuYKPwhmdj8aTGEbz5eO0PKYwgZww2EXw2_tmDUdeGLc1hstqpECkIuOPQ:s9eg4psySfngNUAG09Zqaa
;

create or replace procedure sudoku.sudoku(in v_puzzle varchar(255))  WRAPPED SQL10012 ablGWmdiWmtqTmdmTmtKTmtuUntKUmJyUmZG3odmXidaWmdaWmdy3nJfUzcaGicaG2SRQSQUn16::u2hfibgG3XVgnBlXZi2oRr833hToSO0r7FCnN5j_mvFWui9jkKN4snToW:TU42INyArTqyrnHW0JBtTAbPO20txqSXxWK:hOwEIAECI6Ym9e10lEu3bnUAJjryI6nmPnkfxYsxwwowapMLKAZEHGtCWig6jNo22pP4rJYEup:uWJze9kMbtEv9onY72TPt5SWQ:PRCkaghCxi_4O9Ou4BREBoTNOvrVpgd:ACvgU76g2xoGdPhmDfOJ7s7JBCdzFIQRm69IPm113SV54cy1cAZ:XAeMudaFZSlm03nPAN0Ft1sxp52kazfGFLxHPYGgo07QfPDV3RJwCTUy7xqEMK_NKmiYhxpF6NoV2W5MzJkxpvW2jrNBjozk3L:Bs9bLzWZ5nTweUEDbQ2kz8LvEx78NF8l3:Y4hn13foTGmROBoRPIY1U56rHQ:vJSAY5_rJy_:ub4Q3q19Ektp_uoYUUtqU7eyoJTA089Wx0_C3WlWsPww6WyclzpEp9OpMKWVjwBX2onaAPi3ZDcjTPQGftH5BsgW_Ac8OGYqa6uTID0LaAm5AuJLoQEdjqzlPmSBcOnLX1lXrO5XBdZ_8nfa:okgI1m3dPLTX6PDuHECGe2rsc:_iySKIyf3QxZpkoq9Cdl4Uym1Alq3j_gHv85k8lG2S4Y2mHXv39BOKKjPhbq3ri4x:rjNU_z_e1R:2S5hb4p:LHPcx4twfVG0RsZXAw1JJ0hJd8hTX6c2SYa2muufTy4:cpa3goVVpnzw8qLTNmt34er3yr4NVWZLtN8yZNF8WM98qU72ytC7:BE7FUg53:mkCR7Ne5hZpjrQ9sStoTxi72H5oVxo5dP2NmL16ojpQ1lpk9bJ1AHXjsJXP1vdIt6VHHn8wdsF5TGFzLI382WAt_YAZ3nPodCz_EfTjoSfjmojPee0KMdBHUbBbbmg3cstdlLijghort1oXBZJiP4W5H6Wz6dXHZKu4G9ZkXr1Dghv9BBgUQ0IdI2IJJLPehxx0YhQQP0luvMl0DODQk1oHc3obsLQDc1h1ELBIQTo2fVownORBc1vPk3vj_1QRtpH:KeeYB6SkImv_4qcfWHbvO34X7xJAhM49ATICIc232KFyUnF8thUZBfUt3gfhTukcy9rUyixyf_c8nXBoiktUtTEbUXupjVLQAa2YugngIGi07ZWRWcKrQuDKx2m4yFyAUbSMrmpQs_ozpJB7jYfasKaSKLmazzpMqiTMmz9WLUKV4XgUrJ7di1RJ2ppuRdGnDB6Vcb7EwYx_EYJlIQcc48hUV88mzTzqYHhThxSUAq5Cg36zn681vmDq6S0ZHmLWR9Dflh9JkbOptuG1nPC3wFOxr2Z70BK3kuEKUjm_op5tuDC5TxVf0bEGxsouaD2J9TN6bj2STUVn2LTuFtbpgvuJDoekmQmo8lUDDj73ICgh5HH6r71ziUiVfHXY05P4K_F87:WuqnXYmOQpIxZz5qMT4gm2hGsWlpRw6GYDfJE9nSPUlvmQxIPztNlbSwM5qAOiGx_RxHUdEEX3bmg5CohFbrr1KsHMe9Q8YX1_mxeBtBgEnU8gfOTJ_nvyJoTkADSrEK2t_skZIG5PFd0RhuLkdDmduBhMWh25xuHmZgGQO2yfycOnavKTjuLsqKLyyMZsugJFIuIT5NZKW4qF4_jTHwr6B7qGnJUaiRP:cTunBGi:PZbyH0i3rOmi8ZFoZ6yVD3WY5WGsKrkWFZkRqHliKihL1:VTJE_bBw59dH0yEK23ePCEFUjZ2iysD8bUzjNbCIxpcKc7kGfYjZqBtLb_bagI8CLdG4FoJ2EfurpKCE5IkoCucjb8qG:GYXnpGxQyz3c3Ar6xvqRBTHurLJuX8RcQRo0HfrMBcANn2mY5_hPZtGNDj3QYbARuEsQ1DHYFoVfTFTLuxHy6fct6E0IpwBe1m4aIhcDbeEa7cmbiBte0dBDAEnGUry3QayHBRKp9jLfuwduXnK_iJlEO09pb:I3vLi2:619A:LV71hVBP95xW9qpP715chBi4ZyL0BWSNhBckH_Mt_RHn_o4h8poWqwv3xlJ_xa4VSRqXjw0RCJU71pXXNpkNdkFvECLFUUoyithwVdNmXjjRHLpY3uJkQaAeJsQ:NsnleQ9dINsyGXFHHEUPNtlC1deOjzNyAVUwFBSEiojutxuUiRrMkRX9hzC7a8Mx4GmGaFtgIVZoVD9gEUrej3oxz_veupL9NRhl:UEDPJ:bsBVUsD_1WCiIKoZ7YXVTrse3kLviiKHsoWNTe12XtGzEiQl4lx9vWUZCzfE7p0YZaqUvbBmBZBSdNI2yxkXlcqUkgktJG3:_0Ti7BSWM_rtAkrbmc_uWJyFlXbP:tbj3q_t3jEQTp7g5i737IBxmXqnIUmXBCmrblgXmohweiI4XsC8XtoeOvlyPNenxXnHoS8lRDgMYpgoFTt3YU3XR1mf7ThZxp3tl81tj1:gbhpMnQdKQIUtdyYDy99VJRPgRHAr4tNKLrMh8HM:Ro:DoqgE8NL:7rukGj2u1L69PYVC56P3:L4uc6bz2_qBY5z0PR0Qq29BlWmet8StqDjCzKvjGJg5m27kvVv1eMQnmGNItVSKwDk2pVnVWTAynR:Sx6Xap8VVh6AoylzfOGoOqyRvmW:fHMQK8KncqjmLyov6nMqGsHb2QKJgZJh1gbhiokRlPUiZYy5fUgDtlb2o5P74ffx0xZgBngfAO4OIZofxpPWH2RZIKwM7T6imLjKSTjCK43H6WXeuqBVXOrw9o5QvwTE3bVFuCd:qGATR5OTdVJFbnPALrivSUv_sFN:XezxcpN2jeL354EL0vemwmgi5aOHYy6Hsq2C5mApeeCw2gFveSCUQt6LpmiBjbVwGzepINzRm8E_PG458tr5CUnP95N2qWXIW45rHrNgyALh7qINSCxIpNRcWn4seH6sKPXDcq5Vcy7VIyHZEuiRZzgVsoIdn7apHJ01g:ra23JawkpcbSeEHqYdpcXGhFdGNgISKo4wLg_BablXu_6oMtXgvirUMvNRki1F1aBUpizUV1q3CF6HB_l8q3SBde7oZm7hLcEhOFSleIVunxZiaWgiJbuaAQs59IwYjFGeMvISp:BcXFMmZmlWbgJtJCHsabhr5nygDfBY9wRzMw6oieLKbq5M7lFRna2prn4TmwAHSVcraFMoK3dOyruQ7TMRm3MBrFWwhc2BVShawFImW5IaglliJoTCdgLIrNtX77LKpSxhtZp4LBueK0gesGWb_3kup2gG7_fuBATKRAIrsIdkV31l2ussxpyd5dVkOFzEiLAEhn9cRXc:xxYjDLeCP8toNWA4Z4C1wYM0itDqe9N16nndbk7gTxKjgLjvQ5VbkiZBbWMAdXDYmbvwhZZUK5MJMXcqn5aqTXIeGBZycaj4SeqxWiwcCrgl0mGGbrsSTMZiId3g_MfII9CpefopKnnxIcNRHkLRbWMffDxQcYQOYptyZB1Lahe0robqytNv0tTIcO3hXrqAJIYK0hGKupQUAd2yuybnK6aoi7KlJZZlcF3QnBG:GabnGndKwxvDXfUMG8XSpQBzJneXAgwv6iGwTiliItjjrWC_X9vf1pWXjIOm54ozvIDwEC9PffVjS6RzkzLeSrHbfsAmJkS1xrscrKcB250Me4wnpNeqUt3HGwrbcKJGWSxKGy60kq8X5cr8IY9p0Nv1GbEL4FmPuxhiDL4dD9EY4DftwYmvdz9fgIexJmscpxEV:MuW:8c5tJkUjl2Yp_jszXiEpx6ENl6fQlMrKqGe7ckmcU_MmxtC3gvcG32gj:ZLZ74IeIUtHaeYgc4Dh6VhCldsKgvxiBfPYjHqyutC0hyQI20pjREBtbgWfdWeLBgSKGbOY72LbvdbzAyZExHhawDMnpBB4tsTngGxlDxlOp8GuoMj2_RaDNs4Z4fTwWpgB20WzVgX69zJiPa5HXrPD5YLB6Gb3YS4b19gq5pg4CBAuOjqRCADVoa6kyc7ReXfHSdOh1vLZdANqg98p9hDZ7nJsM72_949Nth5XjrWDfaiBw6RC3h0u:wbzPub5HD0S0V6W8T6qdjF1GwzVQ0knFfSvAJj7bfYeKHSR_3ul63IdnnYvrRDKQs44LvXx4OE779o:IR7pZ8sf72xjYqidtvotRYp83gnk3WEOGhhjl2aLyh_6cIG0U9dq1QBZ:8TPXDDfTEnLboYkmuqFuJdj8qIhc23RBOjpP3GhIXSKBfVQSb1TLyJWbY3EGf_X9wdiY4YxUA_76nrK3azQjwRrAcHn8ey52b0iFba2ttKwkplJ0MKJl_q7mHsGqJ6ajbX3Pj4MWFnwa5Az_2:X_rkF3lpFJmE64FZhymNBql2_Qw5SBdK4NPGiX1FRkgpfwRDYNEYGVzJffODhSCBiYsp3rEO0194ATdwDr4R_kU_mVwXvzQieqHmeotV7q02Al2z:H4kCP:FVcxtmqu652grwREG5fSizCi07dTByA7UOt_AM0scFduAlyXfx73v3GaAR8BGnG9D6HqE6ps3RVPYepKFpbdxSjbbbibGQvJzjiSRr4NLj5ysjtl8p09n5TIoR6ObBI_4:I1XQts1_hKkcc:KpSzHJ7N4bqqx3ywYezaGxIeliB:5uAa7XZxQsPqN7qR6pj9cVK5ugx5lcXV9LfZB6l1ood2r8eioyFo:hgEXLM2aAe4GT2::Qq8lkmFVCR0VtYI:9QTlo9fxt3AHJTy5OVA4oZ9cX99NGM7w:1f7wzt9VAbk0GpoEWzA_TVvT4KH:WMantwI5CW2rTdJcjSQ3d_ReFGRsHJFpQHE:8sSMzmAsLamYj6T6p4jAvKi9pXJ2u32vwdRT_8g5pYLyYLPHRc0o3ROt:0cJMYxpm:knuj8P:N:LtfduqcE7mJXnHi4M5_flBvrb_MZEW7sy9XYLX33jQ5tDB3GUba0aSRVdjUUHBpmDAcZZPK2hWWBxCz6YuFFC9XsvDbLP_dtAnSif_ljYL1Sm25zGR:5azDZzAk7D8OgB9VEpB96VdTxhK3Rw9HAZTkSuNRYi8DEJnPFCh:IVBeBMGbhi9NcKUrISjVZvHPE4TX:EPw_X1UHSwKiobtrVcuOiuuT6WgHY:WiaIg515zaRznGac6TZwXzi_FosFte_omdOF_cberfuStPG1fKuokht2QEPFwKjkUJlnjUIvLNJHjF76okEGIyx726M8ZAmzTc3vl:ADbrFJdXU:fmDahNt_2q5grOkQ2p5uHgwj8ZBiTQWqBxC_6BfLSevA:nLmbsis0V_kLxfP7QtXSZ6RuvE1Nvuv3ac4_Rje8R4m97OJ:9X_5OCYf1j5WrE1zBo788VA79zsmm8LnHlVkSUhizYA0zmiJzHeecWoY:Dg2jCo4CMs_Hva8qjU3LcRzOXDSF4IBEoQrxxrjRlzlRR9YtwxROj7p00tMBOOuAbZ25YxQCumC56gi3q_6J7XBEpRY6N:adeK9Ly:1U232AwE1GF2f3uy3B8ObdeX3o0SydIB3MUbHVcKrOLP4pSOyvgJa_jhN_7mohMIEqhQzbIYICcT1yE4sJ07HaoO2mUI48L8:uiH9v6rIFiYY0pxxkee_G3c5Gek367iGx:aMEgYXcTlZNNhb6Im1o_zhpDc1rzV74dLP4_C7v4UP2mo63XENXSlXeChb_BhJYFCvg:6sMMLmG1dFTm20rlyISIdlgRno4fam5Q23DW9Fm0ay26mrvSoMejvXgEVlgiNndMVCEeLSDv6uVtTLnFCsC6hjAhgxQRouglPmLNDRbCbk2ZK4yuMEn49FahsK5El249CSPYqaPgoe5vCLLzYZOT6XCgXRkiQ5l8AxF8ypyXhbESWEmUsiXcpRktd270lW2c:qV:BfbrVQlGhT6mEAJPhxjnNYLd8u1JljhAANZ9Bd4JMNJW9aQvH7R8_o_Y1OYrMlDV:_CUgrotA_p:_OkCJJt_8tx7KfMoIkVpp98xqPvN2XCqE3KWfR4IoUSmxST4r7vWSZMaaA6XOYr0JWruR4oy7Dg7Il3x_77LPh6xczbdc0FHT2FCL27C8GckHgxUSfcSXj3Hl8L6kLuO:daiML4Z_78HNTnnua0zer784oBKZFYeliNHdkfeToN:LmNxitu1abCYkSBW8V1C8Tf8GDee8fhq033WyrIugjxJ7oNG5nrezBfTrzebSTZS17cjCQyLsSumHNfvdtaPG0bE7gaA4QazWSr8ixuiqIwQ3gcup_cNJPdq4vjD4ltXG9UCFxwxqU_DBSuy4bvjX2aTQjoSq3afjX9U2ziaxAR22MMjVxbLdfbEljqBOxo40WEyFTnpyi3MDGVbSaSLNcTs9DUDATEVb6ED_dX97fe_OX7KLOhUqpFnAEBwdwnRFGyh:TSRNVbWT9g91l2_ETcEwRTFfo98CyWim4:7YJlDe14JIzLYz_OBbFO:luzdqtmMxGQQOyVpfyxCg87vzB2MdhtLnjxVvFMAK4BpZXNH31dxDvehVcGNZXEPvZkSDb6mZcop:FIv2Ym6vwOsTG8Y3IaIw6C3E8ryrxvry2I_8iAQ9G00hhKfpnAsJNSSRHjcSGo5HjBtRDVWNg:EHWY767XYtEMWpOdsazCSA7RSGd2:zXPUtJPoBKC3jZonsrp5wmhSuuTPgKzDuDpB6QoTXdjUwkNOpyRihoCLyEiMkj8LsT9IyRmhpsIZkk7Icjpc1L8DP8nE5ALGVd4OkuHjrEowmUuEeSu_UPwk3RNlC:0JYOAkbA_QzoLfiMtUaKtozrmNCMNaHdWyh4dHXFlc6t:W5kZiI8hOGV0Kl5EEcb9V8upa7tAWZz5K9VyQ2Pujr9FRqy99cK1F8YNbIahROyFRsfoqAcd1WIiSTBaeSAg6PbX8G3Oo7isxthclpekR_QLMlpQ2Ji0R:XvQ:NGAZzO60D0STlbCtJtXC2WPMkyWz66WgTYtoKN_RZtEYLMUISo_Bu:hbPP3e19sjtXXbt0LeO6oD:ZPsjBKatdffKkNa9f3XBaBShwD6yhQNpkdVzsTho9PgNMFszln_RlT2MNewWzGlYzkP3ObXKaUq2rkgzIzkVo5cMVmLsxPTvEm5thhbj6PrKNIoZfuPKm70run9HQWK2NFF:J90n_Th_F:y4WE:VOWNqcUDdBkvXB3WlSKLzUOKCF9zF0M9PXiKKuv8JxEL1MYDKhgIbzPt8Is_xuNofvos5Yqh3G6pW9s:nmlLiPK:_:fdn59IlStQgqX5GlNGYlhrrGxoY3w5j4ARjwdZFNVKSLgC15mhWe6j:nQEHoMRRtdhU7DFOU5ugJNUAr91DCyGQ3Z:2EfaZspkrILFtIfgrl0VJmUNLvCKyNd55FzxXErsymNfEflCcaEIkzF7yyOAY8A0hqEDFamIbAza3x2B6HnGmwaOlBXyA68gcyBihcTOPGEi:r7FmancfRbixQOAhRuanO:CmTYwOCkKVvL:ZYiZsJQUKEy_iT1XH5wi0BLMRKEkCTXrpYcKmJ156Eh8Mq95PqoPrFYpOM_s6NDkH7yHtBI4vMjRAo:1SspOxTJHIc4vKNwn_VzJ_eETme__yuILoBIJ2KbHWaHdgvmFpmrH0WjVgWPmxHk6i4CkZVaEIk9S0ADJH9A:R0ZM95hnT3PqH1NoTrVCnwq6RIWIr:UCQbUhDmDNQwlJ9V1_91VbpFQnmZkqsrFfcrrpaqNFXUksgpPZhWmB2ijzejMfL8ijjuXv:PDzGZ5YJfJS3JCFPbDqouZmYeVOQjfGOTLsZ8Oc1_AMVz033AYF1BBgF9Pgms7BARinHy18PJKk59WObx4jNcwbSHBe2cOFrpnmNS:ATGQLGVWZ8S8kQjtrlS5SK3bWsITmcjEYiwGy39myHJHjgRjrqnDgtmcnqi6l_eq0taoXxY7DYRKMu_i:ar_BJSwgrG6eCUIMXf:H:JTVYtm8GYVL8TH5fuWKcbraUp5oX8FglX:81ZG4Z2sY5TD8vUg0xYVEOHEmhFaBRYVooAE1C7XP0HkARrve5q2koFcgIStWMyxLyOZS:Le1VUYE3LfCH83U_UqVnIx57nP3CyOr7nnz7g2T1Xj0c4MVYRWnU2NOiKeHb0bjHrUvkqfK0i46MjkzYIRsJWrinrQ8Owii_A5a9lmS19U1N9NV6JWxP0rkhNHe7I0O8Jb12Dy0qNZVwcDb8jf0P5uwun9iwhioqtOue3KhXe7mMvjITIzb1PPCSXPAPuiqlv8irmmGlbV7Dvpy:wbygq3YIAjhsG30KrbT3i3Zk4Y5y4jec1Xsyzijfhuicevcu5_FeqgHjaW7_vVAwY40oWtVx88HSk4Q_kdI6zr1DFHSkpbnQzvaO6qDop1YlYgR_pZWB5ovUrimSr1k5uaUmIu5BT5dl6Pn8Riq3:DSAjFUmS5:CyqJfWYY8rF7t2r0H2S8ONc6x6wJbc2QIJoRIYlr46Ww_v1ZyyuOviAyPH1eCCADYwBuboJAKdmUALLlSXncDC1ehV2mhl:dPICMXjX8Fl:fxtSuaszjgf0QiQvXop7kW5E4f26:v76TUHE18Gx9_kB3ofd_8HJOqDdvuBirhjuqqcbZ1:UUJlpz6mvf9zH4uxqrhPb8mA0nS80E8y9hrANNRRuVTUNLpEEP4W394NXVlC8enjommSEl9nAxlW2pK5c_OLaXsV2jqloSxVUW0Dm8dCk_t5UBldZoYXZilsb_aAhghxyD5vwa:aalyb1iS74YLPbo8rZKk0O69PnMEo20wh52asxV_eNJOuMd2TlEWdzCsc6qbvaSbQa1xtKsAJSe08NMoXdhCqPkV8jtZ22T6Hi3SzO1Y8YrFEsjjM_i99MH7ak8vc3AlzQsizdIuErx2ntyV6gM1XVEZiof:W_S0GjXYL9trbk09vchsmOkEQcA8RVdL3on51CAoK5Q4tOZlbjNZ_:32O0Mr5C8p__qeu2oILtXnibbYbm3nabrA2ZoC7gvsXZUqzDMsz9smL4Ew16gHyh0vMX4JZFHVfBCgIoua3GykbVaWea
;
